@@ -3,7 +3,7 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 import traceback
 from sqlbuilder import smartsql as sb
@@ -228,7 +228,7 @@ class Model(ModelBase):
         del self
         if _traceback is not None:
             if _debug:
-                self.logger.debug(traceback.format_exc())
+                print traceback.format_exc()
             return False
         return True
 
